==> elixir-react-native-components-1.0.0.tgz: package/components/key/templates/DynamicJson.js <==
/* eslint-disable no-underscore-dangle */
import React, { useRef, useState, useEffect } from "react";
import { Platform, Text, View } from 'react-native';
import { InputItem, TextareaItem } from "@ant-design/react-native";
import PropTypes from "prop-types";
import LabelComponent from "../label";
import { Styles } from "../../../src-screens/Styles/eliraStyles";
import { Stepper } from '@ant-design/react-native';
import { setObject, sendRefreshRequest } from "elixir-react-stateful/redux/actions";
import store from "elixir-react-stateful/redux";
import { connect } from "react-redux";
import * as Util from "../../../helpers/util";
import MultiSelect from 'react-native-multiple-select';
import * as colors from '../../../src-screens/environments/colors'
import TextField from '@mui/material/TextField';
import Autocomplete, { createFilterOptions } from '@mui/material/Autocomplete';


const DynamicJson = ({ dispatch, meta, value, theme, tdlPath, path, customStyle, vs, isRTL, onClear }) => {

  // use formatField from tdlOptions> get it from object 
  // depending on format we need to draw inputs
  // onchange for each input we should set part of the JSON value and then set object

  const replacedPath = path.replace(/\[[0-9]\]/g, '#*').replace(/\./g, "#");
  let options = vs.tdl.tdlOptions[replacedPath]

  const formatField = options['formatField']
  let jsonMeta = vs.getObject(formatField, "")
  if (jsonMeta != "") {
    const jsonObj = JSON.parse(jsonMeta)
    const { pv, isMandatory, hasPVs, dynamicPossibleValues } = meta;
    // const multiSelect = useRef(null)
    const [selectedItem, setSelectedItem] = useState("")
    const [listIsOpened, setListIsOpened] = useState(false)
    const [arrayValues, setArrayValues] = useState(JSON.parse(value));
    const filter = createFilterOptions();
    const multiSelect = useRef(null)

    useEffect(() => {
      setArrayValues(JSON.parse(value));
    }, [value])
    console.log("bhbhdcdhc",isRTL)
    return <View style={{flexDirection: "column"  }}>

      {Object.keys(jsonObj).map((paramItem) => {
        console.log("m1 == ", paramItem)

        return (
          <>
            <View style={{display:"flex", flexDirection: "column", paddingBottom:10,paddingTop:10 ,width:"100%" ,marginBottom:10}}>
              <Text style={[Styles.textStyle, {
               flex: theme.keyLabel.flex,
               flexDirection: isRTL ? 'row-reverse' : 'row',
               fontSize: 15,
               fontFamily:"AlmaraiRegular",
               textAlign: isRTL ? 'right' : 'left',
               color:"black"
              }]}>{isRTL ? jsonObj[paramItem].labelAr : jsonObj[paramItem].labelEn}</Text>
              {jsonObj[paramItem].type == "String" && (jsonObj[paramItem].pvs == null || jsonObj[paramItem].pvs == "") ? (

                <View style={{ flex: 1, padding: 5 }}>
                  <InputItem
                    style={{
                      padding: 5,
                      textAlign: isRTL?"right":"left",
                    }}
                    onChange={(v) => {

                      let jsonValue = JSON.parse(value);
                      jsonValue[paramItem] = v
                      store.dispatch(setObject(vs.usecaseId, path, JSON.stringify(jsonValue)));

                    }}
                    type={"text"}
                    value={value && JSON.parse(value)[paramItem]}
                    contextMenuHidden={true}
                    selectTextOnFocus={false}
                    customStyle={customStyle}

                  />
                </View>

              ) : jsonObj[paramItem].type == "Double" ? (
                <View style={{ flex: 1, paddingBottom: 20 }}>
                  <Stepper
                    step={100}
                    style={[Styles.borderStyle, {}]}
                    defaultValue={value && JSON.parse(value)[paramItem] || 0.0}
                    value={value && JSON.parse(value)[paramItem] || 0.0}
                    onChange={(v) => {

                      let jsonValue = JSON.parse(value);
                      jsonValue[paramItem] = v

                      store.dispatch(setObject(vs.usecaseId, path, JSON.stringify(jsonValue)));

                    }}
                    customStyle={customStyle}

                  />

                </View>) :
                jsonObj[paramItem].type == "String" && jsonObj[paramItem].pvs != null && jsonObj[paramItem].pvs != "" ? (

                  <View style={{ flex: 1, padding: 5 }}>
                    {Platform.OS == "web" &&
                      <Autocomplete
                        value={arrayValues[paramItem]}
                        blurOnSelect={true}
                        onChange={(event, v) => {
                          // val = val[0]
                          let jsonValue = JSON.parse(value);
                          setSelectedItem(v)

                          jsonValue[paramItem] = v
                          store.dispatch(setObject(vs.usecaseId, path, JSON.stringify(jsonValue)));
                          setListIsOpened(false)
                          setArrayValues(JSON.parse(value));
                        }}
                        onKeyDown={(e) => {
                          console.log("e.keyCode", e.keyCode)
                          if (e.keyCode === 9) e.preventDefault();
                        }}
                        filterOptions={(options, params) => {
                          const filtered = filter(options, params);

                          const { inputValue } = params;
                          // Suggest the creation of a new value
                          const isExisting = options.some((option) => inputValue === option.id);
                          if (inputValue !== '' && !isExisting) {
                            filtered.push({
                              inputValue,
                              id: `Add "${inputValue}"`,
                            });
                          }

                          return filtered;
                        }}
                        open={listIsOpened}
                        onOpen={() => {
                          // if (!pv || pv.length === 0) onQuery("");
                          console.log("Najma Islam Altair",jsonObj[paramItem].pvs)
                          setListIsOpened(true)
                        }}
                        onClose={() => {
                          setListIsOpened(false);
                        }}
                        selectOnFocus
                        clearOnBlur
                        handleHomeEndKeys
                        id="id"
                        options={jsonObj[paramItem].pvs}
                        getOptionLabel={(option) => {
                          // Value selected with enter, right from the input
                          if (typeof option === 'string') {
                            return option;
                          }
                          // Add "xxx" option created dynamically
                          if (option.inputValue) {
                            return option.inputValue;
                          }
                          // Regular option
                          return option.id;
                        }}
                        renderOption={(props, option) => <li {...props}>{option.id}</li>}
                        sx={{ width: 300 }}
                        freeSolo
                        renderInput={(params) => (
                          <TextField {...params} label="" />
                        )}
                        uniqueKey="id"
                        ref={(component) => { multiSelect.current = component }}
                        style={{ width: "100%" }}
                      />
                    }
                    {Platform.OS != "web" &&
                      <MultiSelect
                        hideTags
                        items={jsonObj[paramItem].pvs}
                        uniqueKey="id"
                        onSelectedItemsChange={(v) => {
                          v = v[0]
                          let jsonValue = JSON.parse(value);
                          setSelectedItem(v)

                          jsonValue[paramItem] = v
                          store.dispatch(setObject(vs.usecaseId, path, JSON.stringify(jsonValue)));
                          setListIsOpened(false)
                          setArrayValues(JSON.parse(value));

                        }}
                        onClearSelector={() => { setSelectedItem(""); setListIsOpened(false) }}
                        selectText={arrayValues[paramItem]}
                        selectedItems={selectedItem}
                        altFontFamily="AlmaraiLight"
                        fontFamily="AlmaraiLight"
                        tagRemoveIconColor="#CCC"
                        tagBorderColor="#CCC"
                        tagTextColor="#CCC"
                        displayKey="id"
                        submitButtonColor="#CCC"
                        styleDropdownMenu={[Styles.borderStyle, {
                          marginLeft: -40,
                          marginRight: -5,

                        }]}
                        itemFontSize={14}
                        fontSize={Styles.fontSize}
                        selectedItemTextColor={colors.Cutty_Sark}
                        selectedItemIconColor={colors.Cutty_Sark}
                        itemTextColor={colors.BLACK}
                        textColor={colors.text_color}
                        styleItemsContainer={{ padding: 10, }}
                        styleRowList={{
                          flex: 1,
                          alignContent: 'center',
                          justifyContent: 'center',
                          borderColor: colors.DOVE_GRAY,
                          borderWidth: 0.2,


                        }}
                        styleTextDropdownSelected={{
                          textAlign: "auto",
                          fontFamily: "AlmaraiLight",
                          height: "100%",


                        }}
                        styleListContainer={{
                          flex: 1,
                          elevation: 1,
                          backgroundColor: colors.Geyser,
                          paddingVertical: 5,
                          borderWidth: 0.2,
                          borderRadius: 2,
                        }}
                        styleInputGroup={{
                          flex: 1,
                          borderWidth: 0.4,
                          borderRadius: 5,
                        }}
                        styleTextDropdown={{ fontSize: 15, fontFamily: "AlmaraiLight", textAlign: "right", textAlignVertical: "bottom" }}
                        searchInputStyle={{ flex: 1, color: colors.DARK_GRAY }}
                        styleMainWrapper={listIsOpened ? {} : {}}
                        single={true}
                      />
                    }

                  </View>


                ) :
                  <></>
              }
            </View>
          </>
        )


      })
      }
    </View>
  }



};



DynamicJson.propTypes = {
  meta: PropTypes.objectOf(PropTypes.any).isRequired,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
  theme: PropTypes.objectOf(PropTypes.any).isRequired,
  isRTL: PropTypes.bool.isRequired,
  onChange: PropTypes.func.isRequired,
  onClear: PropTypes.func.isRequired,
};

DynamicJson.defaultProps = {
  value: null,
  customStyle: {}
};
const mapStateToProps = (state) => ({
  isRTL: state.general.isRTL,
});

export default connect(mapStateToProps)(React.memo(DynamicJson, Util.isEqual));

==> elixir-react-native-components-1.2.0.tgz: package/components/key/templates/DynamicJson.js <==
/* eslint-disable no-underscore-dangle */
import React, { useRef, useState, useEffect } from "react";
import { Platform, Text, View } from 'react-native';
import { InputItem, TextareaItem } from "@ant-design/react-native";
import PropTypes from "prop-types";
import LabelComponent from "../label";
import { Styles } from "../../../src-screens/Styles/eliraStyles";
import { Stepper } from '@ant-design/react-native';
import { setObject, sendRefreshRequest } from "@muhammadz/elixir-react-stateful/redux/actions";
import store from "@muhammadz/elixir-react-stateful/redux";
import { connect } from "react-redux";
import * as Util from "../../../helpers/util";
import MultiSelect from 'react-native-multiple-select';
import * as colors from '../../../src-screens/environments/colors'
import TextField from '@mui/material/TextField';
import Autocomplete, { createFilterOptions } from '@mui/material/Autocomplete';


const DynamicJson = ({ dispatch, meta, value, theme, tdlPath, path, customStyle, vs, isRTL, onClear }) => {

  // use formatField from tdlOptions> get it from object 
  // depending on format we need to draw inputs
  // onchange for each input we should set part of the JSON value and then set object

  const replacedPath = path.replace(/\[[0-9]\]/g, '#*').replace(/\./g, "#");
  let options = vs.tdl.tdlOptions[replacedPath]

  const formatField = options['formatField']
  let jsonMeta = vs.getObject(formatField, "")
  if (jsonMeta != "") {
    const jsonObj = JSON.parse(jsonMeta)
    const { pv, isMandatory, hasPVs, dynamicPossibleValues } = meta;
    // const multiSelect = useRef(null)
    const [selectedItem, setSelectedItem] = useState("")
    const [listIsOpened, setListIsOpened] = useState(false)
    const [arrayValues, setArrayValues] = useState(JSON.parse(value));
    const filter = createFilterOptions();
    const multiSelect = useRef(null)

    useEffect(() => {
      setArrayValues(JSON.parse(value));
    }, [value])
    console.log("bhbhdcdhc",isRTL)
    return <View style={{flexDirection: "column"  }}>

      {Object.keys(jsonObj).map((paramItem) => {
        console.log("m1 == ", paramItem)

        return (
          <>
            <View style={{display:"flex", flexDirection: "column", paddingBottom:10,paddingTop:10 ,width:"100%" ,marginBottom:10}}>
              <Text style={[Styles.textStyle, {
               flex: theme.keyLabel.flex,
               flexDirection: isRTL ? 'row-reverse' : 'row',
               fontSize: 15,
               fontFamily:"AlmaraiRegular",
               textAlign: isRTL ? 'right' : 'left',
               color:"black"
              }]}>{isRTL ? jsonObj[paramItem].labelAr : jsonObj[paramItem].labelEn}</Text>
              {jsonObj[paramItem].type == "String" && (jsonObj[paramItem].pvs == null || jsonObj[paramItem].pvs == "") ? (

                <View style={{ flex: 1, padding: 5 }}>
                  <InputItem
                    style={{
                      padding: 5,
                      textAlign: isRTL?"right":"left",
                    }}
                    onChange={(v) => {

                      let jsonValue = JSON.parse(value);
                      jsonValue[paramItem] = v
                      store.dispatch(setObject(vs.usecaseId, path, JSON.stringify(jsonValue)));

                    }}
                    type={"text"}
                    value={value && JSON.parse(value)[paramItem]}
                    contextMenuHidden={true}
                    selectTextOnFocus={false}
                    customStyle={customStyle}

                  />
                </View>

              ) : jsonObj[paramItem].type == "Double" ? (
                <View style={{ flex: 1, paddingBottom: 20 }}>
                  <Stepper
                    step={100}
                    style={[Styles.borderStyle, {}]}
                    defaultValue={value && JSON.parse(value)[paramItem] || 0.0}
                    value={value && JSON.parse(value)[paramItem] || 0.0}
                    onChange={(v) => {

                      let jsonValue = JSON.parse(value);
                      jsonValue[paramItem] = v

                      store.dispatch(setObject(vs.usecaseId, path, JSON.stringify(jsonValue)));

                    }}
                    customStyle={customStyle}

                  />

                </View>) :
                jsonObj[paramItem].type == "String" && jsonObj[paramItem].pvs != null && jsonObj[paramItem].pvs != "" ? (

                  <View style={{ flex: 1, padding: 5 }}>
                    {Platform.OS == "web" &&
                      <Autocomplete
                        value={arrayValues[paramItem]}
                        blurOnSelect={true}
                        onChange={(event, v) => {
                          // val = val[0]
                          let jsonValue = JSON.parse(value);
                          setSelectedItem(v)

                          jsonValue[paramItem] = v
                          store.dispatch(setObject(vs.usecaseId, path, JSON.stringify(jsonValue)));
                          setListIsOpened(false)
                          setArrayValues(JSON.parse(value));
                        }}
                        onKeyDown={(e) => {
                          console.log("e.keyCode", e.keyCode)
                          if (e.keyCode === 9) e.preventDefault();
                        }}
                        filterOptions={(options, params) => {
                          const filtered = filter(options, params);

                          const { inputValue } = params;
                          // Suggest the creation of a new value
                          const isExisting = options.some((option) => inputValue === option.id);
                          if (inputValue !== '' && !isExisting) {
                            filtered.push({
                              inputValue,
                              id: `Add "${inputValue}"`,
                            });
                          }

                          return filtered;
                        }}
                        open={listIsOpened}
                        onOpen={() => {
                          // if (!pv || pv.length === 0) onQuery("");
                          console.log("Najma Islam Altair",jsonObj[paramItem].pvs)
                          setListIsOpened(true)
                        }}
                        onClose={() => {
                          setListIsOpened(false);
                        }}
                        selectOnFocus
                        clearOnBlur
                        handleHomeEndKeys
                        id="id"
                        options={jsonObj[paramItem].pvs}
                        getOptionLabel={(option) => {
                          // Value selected with enter, right from the input
                          if (typeof option === 'string') {
                            return option;
                          }
                          // Add "xxx" option created dynamically
                          if (option.inputValue) {
                            return option.inputValue;
                          }
                          // Regular option
                          return option.id;
                        }}
                        renderOption={(props, option) => <li {...props}>{option.id}</li>}
                        sx={{ width: 300 }}
                        freeSolo
                        renderInput={(params) => (
                          <TextField {...params} label="" />
                        )}
                        uniqueKey="id"
                        ref={(component) => { multiSelect.current = component }}
                        style={{ width: "100%" }}
                      />
                    }
                    {Platform.OS != "web" &&
                      <MultiSelect
                        hideTags
                        items={jsonObj[paramItem].pvs}
                        uniqueKey="id"
                        onSelectedItemsChange={(v) => {
                          v = v[0]
                          let jsonValue = JSON.parse(value);
                          setSelectedItem(v)

                          jsonValue[paramItem] = v
                          store.dispatch(setObject(vs.usecaseId, path, JSON.stringify(jsonValue)));
                          setListIsOpened(false)
                          setArrayValues(JSON.parse(value));

                        }}
                        onClearSelector={() => { setSelectedItem(""); setListIsOpened(false) }}
                        selectText={arrayValues[paramItem]}
                        selectedItems={selectedItem}
                        altFontFamily="AlmaraiLight"
                        fontFamily="AlmaraiLight"
                        tagRemoveIconColor="#CCC"
                        tagBorderColor="#CCC"
                        tagTextColor="#CCC"
                        displayKey="id"
                        submitButtonColor="#CCC"
                        styleDropdownMenu={[Styles.borderStyle, {
                          marginLeft: -40,
                          marginRight: -5,

                        }]}
                        itemFontSize={14}
                        fontSize={Styles.fontSize}
                        selectedItemTextColor={colors.Cutty_Sark}
                        selectedItemIconColor={colors.Cutty_Sark}
                        itemTextColor={colors.BLACK}
                        textColor={colors.text_color}
                        styleItemsContainer={{ padding: 10, }}
                        styleRowList={{
                          flex: 1,
                          alignContent: 'center',
                          justifyContent: 'center',
                          borderColor: colors.DOVE_GRAY,
                          borderWidth: 0.2,


                        }}
                        styleTextDropdownSelected={{
                          textAlign: "auto",
                          fontFamily: "AlmaraiLight",
                          height: "100%",


                        }}
                        styleListContainer={{
                          flex: 1,
                          elevation: 1,
                          backgroundColor: colors.Geyser,
                          paddingVertical: 5,
                          borderWidth: 0.2,
                          borderRadius: 2,
                        }}
                        styleInputGroup={{
                          flex: 1,
                          borderWidth: 0.4,
                          borderRadius: 5,
                        }}
                        styleTextDropdown={{ fontSize: 15, fontFamily: "AlmaraiLight", textAlign: "right", textAlignVertical: "bottom" }}
                        searchInputStyle={{ flex: 1, color: colors.DARK_GRAY }}
                        styleMainWrapper={listIsOpened ? {} : {}}
                        single={true}
                      />
                    }

                  </View>


                ) :
                  <></>
              }
            </View>
          </>
        )


      })
      }
    </View>
  }



};



DynamicJson.propTypes = {
  meta: PropTypes.objectOf(PropTypes.any).isRequired,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
  theme: PropTypes.objectOf(PropTypes.any).isRequired,
  isRTL: PropTypes.bool.isRequired,
  onChange: PropTypes.func.isRequired,
  onClear: PropTypes.func.isRequired,
};

DynamicJson.defaultProps = {
  value: null,
  customStyle: {}
};
const mapStateToProps = (state) => ({
  isRTL: state.general.isRTL,
});

export default connect(mapStateToProps)(React.memo(DynamicJson, Util.isEqual));
